# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2021-02-14 18:48
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import submission.models


def migrate_keywords(apps, schema_editor):
    Article = apps.get_model('submission', 'Article')
    KeywordArticle = apps.get_model('submission', 'KeywordArticle')
    articles = Article.objects.filter(keywords__isnull=False)

    for article in Article.objects.all():
        for i,kw in enumerate(article.keywords.all()):
            kw_article, _ = KeywordArticle.objects.get_or_create(
                keyword=kw,
                article=article,
            )
            kw_article.order = i
            kw_article.save()


def demigrate_keywords(apps, schema_editor):
    KeywordArticle = apps.get_model('submission', 'KeywordArticle')

    for kw_article in KeywordArticle.objects.all():
        kw_article.article.keywords.add(kw_article.keyword)


class Migration(migrations.Migration):

    dependencies = [
        ('submission', '0049_auto_20201117_1904'),
    ]

    operations = [
        # Allow usage of Article.objects
        migrations.AlterModelManagers(
            name='article',
            managers=[
                ('allarticles', django.db.models.manager.Manager()),
                ('objects', submission.models.ArticleManager()),
            ],
        ),
        # Create new through model
        migrations.CreateModel(
            name='KeywordArticle',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order', models.PositiveIntegerField(default=1)),
            ],
            options={
                'ordering': ['order'],
            },
        ),
        migrations.AddField(
            model_name='keywordarticle',
            name='article',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='submission.Article'),
        ),
        migrations.AddField(
            model_name='keywordarticle',
            name='keyword',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='submission.Keyword'),
        ),
        migrations.AlterUniqueTogether(
            name='keywordarticle',
            unique_together=set([('keyword', 'article')]),
        ),
        # Add temporary relation to new through model
        migrations.RunPython(migrate_keywords, reverse_code=demigrate_keywords),
        # Replace old relation with the new one
        migrations.RemoveField(
            model_name='article',
            name='keywords',
        ),
        migrations.AddField(
            model_name='article',
            name='keywords',
            field=models.ManyToManyField(blank=True, null=True, through='submission.KeywordArticle', to='submission.Keyword'),
        ),
    ]
